.. Tenks documentation master file, created by
   sphinx-quickstart on Thu Sep 20 15:43:21 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Tenks's documentation!
=================================

Tenks is a utility that manages virtual bare metal clusters for development and
testing purposes.

.. toctree::
   :maxdepth: 2

   configuration
   install
   run
   architecture
   development
   limitations
